@@ -11,43 +11,44 @@ import urllib
 
 import glib
 
+
 logger = logging.getLogger('mopidy.utils.path')
 
-XDG_CACHE_DIR = glib.get_user_cache_dir().decode('utf-8')
-XDG_CONFIG_DIR = glib.get_user_config_dir().decode('utf-8')
-XDG_DATA_DIR = glib.get_user_data_dir().decode('utf-8')
-XDG_MUSIC_DIR = glib.get_user_special_dir(glib.USER_DIRECTORY_MUSIC)
-if XDG_MUSIC_DIR:
-    XDG_MUSIC_DIR = XDG_MUSIC_DIR.decode('utf-8')
+
 XDG_DIRS = {
-    'XDG_CACHE_DIR': XDG_CACHE_DIR,
-    'XDG_CONFIG_DIR': XDG_CONFIG_DIR,
-    'XDG_DATA_DIR': XDG_DATA_DIR,
-    'XDG_MUSIC_DIR': XDG_MUSIC_DIR,
+    'XDG_CACHE_DIR': glib.get_user_cache_dir(),
+    'XDG_CONFIG_DIR': glib.get_user_config_dir(),
+    'XDG_DATA_DIR': glib.get_user_data_dir(),
+    'XDG_MUSIC_DIR': glib.get_user_special_dir(glib.USER_DIRECTORY_MUSIC),
 }
-DATA_PATH = os.path.join(unicode(XDG_DATA_DIR), 'mopidy')
-SETTINGS_PATH = os.path.join(unicode(XDG_CONFIG_DIR), 'mopidy')
-SETTINGS_FILE = os.path.join(unicode(SETTINGS_PATH), 'settings.py')
+
+# XDG_MUSIC_DIR can be none, so filter out any bad data.
+XDG_DIRS = dict((k, v) for k, v in XDG_DIRS.items() if v is not None)
 
 
-def get_or_create_folder(folder):
-    folder = os.path.expanduser(folder)
-    if os.path.isfile(folder):
+def get_or_create_dir(dir_path):
+    if not isinstance(dir_path, bytes):
+        raise ValueError('Path is not a bytestring.')
+    dir_path = expand_path(dir_path)
+    if os.path.isfile(dir_path):
         raise OSError(
             'A file with the same name as the desired dir, '
-            '"%s", already exists.' % folder)
-    elif not os.path.isdir(folder):
-        logger.info('Creating dir %s', folder)
-        os.makedirs(folder, 0755)
-    return folder
+            '"%s", already exists.' % dir_path)
+    elif not os.path.isdir(dir_path):
+        logger.info('Creating dir %s', dir_path)
+        os.makedirs(dir_path, 0755)
+    return dir_path
 
 
-def get_or_create_file(filename):
-    filename = os.path.expanduser(filename)
-    if not os.path.isfile(filename):
-        logger.info('Creating file %s', filename)
-        open(filename, 'w')
-    return filename
+def get_or_create_file(file_path):
+    if not isinstance(file_path, bytes):
+        raise ValueError('Path is not a bytestring.')
+    file_path = expand_path(file_path)
+    get_or_create_dir(os.path.dirname(file_path))
+    if not os.path.isfile(file_path):
+        logger.info('Creating file %s', file_path)
+        open(file_path, 'w').close()
+    return file_path
 
 
 def path_to_uri(*paths):
@@ -99,7 +100,13 @@ def split_path(path):
 
 
 def expand_path(path):
-    path = string.Template(path).safe_substitute(XDG_DIRS)
+    # TODO: document as we want people to use this.
+    if not isinstance(path, bytes):
+        raise ValueError('Path is not a bytestring.')
+    try:
+        path = string.Template(path).substitute(XDG_DIRS)
+    except KeyError:
+        return None
     path = os.path.expanduser(path)
     path = os.path.abspath(path)
     return path
@@ -123,7 +130,7 @@ def find_files(path):
         for dirpath, dirnames, filenames in os.walk(path, followlinks=True):
             for dirname in dirnames:
                 if dirname.startswith(b'.'):
-                    # Skip hidden folders by modifying dirnames inplace
+                    # Skip hidden dirs by modifying dirnames inplace
                     dirnames.remove(dirname)
 
             for filename in filenames:
