@@ -9,9 +9,12 @@ from mopidy.backends import listener
 
 @mock.patch.object(listener.BackendListener, 'send')
 class BackendEventsTest(object):
+    config = {}
+
     def setUp(self):
         self.audio = audio.DummyAudio.start().proxy()
-        self.backend = self.backend_class.start(audio=self.audio).proxy()
+        self.backend = self.backend_class.start(
+            config=self.config, audio=self.audio).proxy()
         self.core = core.Core.start(backends=[self.backend]).proxy()
 
     def tearDown(self):
